@@ -12,10 +12,12 @@ def downloadMordorFile(url, dest="/tmp/"):
     if url[-7:] == '.tar.gz':
         mordorFile = downloadFile(url)
         mordorJSONPath = decompressJSON(mordorFile)
-        return mordorJSONPath
     elif url[-4:] == '.zip':
-        mordorJSONPath = getMordorZipFile(url)
-        return mordorJSONPath
+        url = url + '?raw=true'
+        zipFileRequest = requests.get(url)
+        zipFile = ZipFile(BytesIO(zipFileRequest.content))
+        mordorJSONPath = zipFile.extract(zipFile.namelist()[0])
+    return mordorJSONPath
     
 def registerMordorSQLTable(spark, url, tableName):
     mordorJSONPath = downloadMordorFile(url)
